@@ -1,14 +1,18 @@
+# Keep imports sorted alphabetically
 import fabtools.cron
 import fabtools.deb
 import fabtools.files
 import fabtools.group
-import fabtools.postgres
 import fabtools.mysql
 import fabtools.network
+import fabtools.nginx
 import fabtools.nodejs
 import fabtools.openvz
+import fabtools.pkg
+import fabtools.postgres
 import fabtools.python
 import fabtools.python_distribute
+import fabtools.rpm
 import fabtools.service
 import fabtools.shorewall
 import fabtools.supervisor
