@@ -8,7 +8,7 @@ and repositories.
 """
 from __future__ import with_statement
 
-from fabric.api import *
+from fabric.api import hide, run, settings
 
 from fabtools.utils import run_as_root
 
