@@ -16,7 +16,7 @@ from distutils.version import StrictVersion as V
 import os
 import posixpath
 
-from fabric.api import *
+from fabric.api import cd, hide, prefix, run, settings, sudo
 from fabric.utils import puts
 
 from fabtools.utils import run_as_root
@@ -74,7 +74,8 @@ def is_installed(package):
     return (package in packages)
 
 
-def install(packages, upgrade=False, use_mirrors=True, use_sudo=False, user=None, download_cache=None):
+def install(packages, upgrade=False, use_mirrors=True, use_sudo=False,
+            user=None, download_cache=None):
     """
     Install Python package(s) using `pip`_.
 
@@ -108,7 +109,8 @@ def install(packages, upgrade=False, use_mirrors=True, use_sudo=False, user=None
         run(command)
 
 
-def install_requirements(filename, upgrade=False, use_mirrors=True, use_sudo=False, user=None, download_cache=None):
+def install_requirements(filename, upgrade=False, use_mirrors=True,
+                         use_sudo=False, user=None, download_cache=None):
     """
     Install Python packages from a pip `requirements file`_.
 
