@@ -11,10 +11,20 @@ and installing packages using `pip`_.
 """
 import posixpath
 
+from fabric.api import run, sudo
+
 from fabtools.files import is_file
-from fabtools.python import *
-from fabtools.python_distribute import is_distribute_installed, install_distribute
-from fabtools.require import deb
+from fabtools.python import (
+    install,
+    install_pip,
+    install_requirements,
+    is_installed,
+    is_pip_installed,
+)
+from fabtools.python_distribute import (
+    install_distribute,
+    is_distribute_installed,
+)
 
 
 DEFAULT_PIP_VERSION = '1.2.1'
@@ -26,7 +36,10 @@ def distribute():
 
     .. _distribute: http://packages.python.org/distribute/
     """
-    deb.packages([
+
+    from fabtools.require.deb import packages as require_packages
+
+    require_packages([
         'curl',
         'python-dev',
     ])
@@ -90,7 +103,7 @@ def requirements(filename, **kwargs):
 
 
 def virtualenv(directory, system_site_packages=False, python=None,
-    use_sudo=False, user=None, clear=False):
+               use_sudo=False, user=None, clear=False):
     """
     Require a Python `virtual environment`_.
 
