@@ -3,15 +3,13 @@ System users
 ============
 """
 from fabtools.files import is_file
-from fabtools.user import *
+from fabtools.user import create, exists, modify
 from fabtools.utils import run_as_root
 
-import fabtools.require
-
 
 def user(name, comment=None, home=None, create_home=True, skeleton_dir=None,
-    group=None, create_group=True, extra_groups=None, password=None,
-    system=False, shell=None, uid=None):
+         group=None, create_group=True, extra_groups=None, password=None,
+         system=False, shell=None, uid=None):
     """
     Require a user and its home directory.
 
@@ -36,20 +34,22 @@ def user(name, comment=None, home=None, create_home=True, skeleton_dir=None,
 
     """
 
+    from fabtools.require import directory as require_directory
+
     # Make sure the user exists
     if not exists(name):
         create(name, comment=comment, home=home, create_home=create_home,
-            skeleton_dir=skeleton_dir, group=group, create_group=create_group,
-            extra_groups=extra_groups, password=password, system=system,
-            shell=shell, uid=uid)
+               skeleton_dir=skeleton_dir, group=group,
+               create_group=create_group, extra_groups=extra_groups,
+               password=password, system=system, shell=shell, uid=uid)
     else:
         modify(name, comment=comment, home=home, group=group,
-            extra_groups=extra_groups, password=password,
-            shell=shell, uid=uid)
+               extra_groups=extra_groups, password=password,
+               shell=shell, uid=uid)
 
     # Make sure the home directory exists and is owned by user
     if home:
-        fabtools.require.directory(home, owner=name, use_sudo=True)
+        require_directory(home, owner=name, use_sudo=True)
 
 
 def sudoer(username, hosts="ALL", operators="ALL", passwd=False, commands="ALL"):
