@@ -1,14 +1,13 @@
 from __future__ import with_statement
 
 import os
-import os.path
 
 try:
     import unittest2 as unittest
 except ImportError:
     import unittest
 
-from fabric.api import *
+from fabric.api import env, hide, lcd, local, settings, shell_env
 from fabric.state import connections
 
 import fabtools
@@ -108,7 +107,7 @@ class VagrantTestSuite(unittest.BaseTestSuite):
         with lcd(os.path.dirname(__file__)):
 
             if not os.path.exists('Vagrantfile') \
-            or not os.environ.get('FABTOOLS_TEST_NODESTROY'):
+               or not os.environ.get('FABTOOLS_TEST_NODESTROY'):
 
                 # Create a fresh vagrant config file
                 local('rm -f Vagrantfile')
@@ -161,7 +160,7 @@ class VagrantTestSuite(unittest.BaseTestSuite):
 
         kwargs['host_string'] = "%s@%s:%s" % (user, hostname, port)
         kwargs['user'] = user
-        kwargs['key_filename'] = config['IdentityFile']
+        kwargs['key_filename'] = config['IdentityFile'].strip('"')
         kwargs['disable_known_hosts'] = True
 
         return settings(*args, **kwargs)
@@ -182,7 +181,9 @@ class VagrantTestCase(unittest.TestCase):
         Run the test case within a Fabric context manager
         """
         with self._suite.settings():
-            unittest.TestCase.run(self, result)
+            http_proxy = os.environ.get('FABTOOLS_HTTP_PROXY', '')
+            with shell_env(http_proxy=http_proxy):
+                unittest.TestCase.run(self, result)
 
     def runTest(self):
         self._callable()
